@@ -65,16 +65,10 @@ newfile() {
 
 mkdir -p "$VVM_BASE_DIR"
 
-if command -v systemctl > /dev/null; then
-	SERVICE="systemctl --user"
-else
-	SERVICE=superctl
-fi
-
-$SERVICE stop vvmd
+systemctl --user stop vvmd
 
 finish() {
-	$SERVICE start vvmd
+	systemctl --user start vvmd
 }
 trap 'finish' EXIT
 
