@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 550c3cf99806ae6ef7a5bc3f5c07826e
+# configversion: bbf3065d8cdf8e8c2ca6382c3c091772
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -15,10 +15,14 @@
 XPROPOUT="$(sxmo_wm.sh focusedwindow)"
 WMCLASS="${1:-$(printf %s "$XPROPOUT" | grep app: | cut -d" " -f2- | tr '[:upper:]' '[:lower:]')}"
 
-service_isrunning() {
+superd_service_isrunning() {
 	superctl status "$1" | grep -q started
 }
 
+sxmo_service_isrunning() {
+	sxmo_daemons.sh running "$1" > /dev/null
+}
+
 if [ -z "$XPROPOUT" ]; then
 	sxmo_log "detected no active window, no problem, opening system menu"
 else
@@ -44,10 +48,7 @@ case "$WMCLASS" in
 				sxmo_daemons.sh running modem_monitor -q &&
 				printf %b "$icon_ton ^ 1 ^ sxmo_daemons.sh stop modem_monitor" || printf %b "$icon_tof ^ 1 ^ sxmo_daemons.sh start modem_monitor sxmo_modemmonitor.sh"
 			) && sxmo_hook_statusbar.sh modem_monitor
-			$icon_phn Modem Daemons $(
-				sxmo_modemdaemons.sh status > /dev/null &&
-				printf %b "$icon_ton ^ 1 ^ sxmo_modemdaemons.sh stop" || printf %b "$icon_tof ^ 1 ^ sxmo_modemdaemons.sh start"
-			) && sxmo_hook_statusbar.sh modem
+			$icon_wrh Restart System Daemons     ^ 1 ^ sxmo_hook_restart_modem_daemons.sh && sxmo_hook_statusbar.sh modem
 			$icon_inf Modem Info                 ^ 0 ^ sxmo_modeminfo.sh
 			$icon_phl Modem Log                  ^ 0 ^ sxmo_modemlog.sh
 			$icon_img Config MMS                 ^ 1 ^ sxmo_mmsdconfig.sh
@@ -71,7 +72,7 @@ case "$WMCLASS" in
 				printf %b "$icon_tof ^ 1 ^ sxmo_wm.sh inputevent stylus on"
 			)
 			$icon_cfg Gestures $(
-				service_isrunning "sxmo_hook_lisgd" &&
+				superd_service_isrunning "sxmo_hook_lisgd" &&
 				printf "%s" "$icon_ton" || printf "%s" "$icon_tof"
 			) ^ 1 ^ supertoggle_daemon 'sxmo_hook_lisgd'
 			$icon_cfg Toggle Bar ^ 0 ^ sxmo_wm.sh togglebar
@@ -81,9 +82,15 @@ case "$WMCLASS" in
 				printf %b "^ 1 ^ doas sxmo_bluetoothtoggle.sh && sxmo_hook_statusbar.sh bluetooth"
 			)
 			$icon_wif Wifi $(
-				rfkill list wifi | grep -q "yes" &&
-				printf %b "$icon_tof" ||  printf %b "$icon_ton";
-				printf %b "^ 1 ^ doas sxmo_wifitoggle.sh && sxmo_hook_statusbar.sh wifi"
+				if rfkill list wifi | grep -q "yes"; then
+					printf %b "$icon_tof"
+					printf %b "^ 1 ^ doas sxmo_wifitoggle.sh"
+				else
+					printf %b "$icon_ton"
+					# fake trigger to update status bar
+					devicename="$(nmcli -t c show --active | grep '802-11-wireless' | cut -d':' -f4)"
+					printf %b "^ 1 ^ doas sxmo_wifitoggle.sh && sxmo_hook_statusbar.sh network wifi \"$devicename\""
+				fi
 			)
 			$(test "$SXMO_WM" = dwm && printf %b "$icon_cfg Invert Colors ^ 1 ^ xcalib -a -invert")
 			$icon_clk Change Timezone            ^ 1 ^ sxmo_timezonechange.sh
@@ -117,8 +124,11 @@ case "$WMCLASS" in
 			$icon_lck Lock               ^ 0 ^ sxmo_hook_lock.sh
 			$icon_lck Lock (Screen off)  ^ 0 ^ sxmo_hook_screenoff.sh
 			$icon_zzz Suspend            ^ 0 ^ sxmo_hook_screenoff.sh && sxmo_suspend.sh
-			$icon_out Logout             ^ 0 ^ confirm Logout && (pkill -9 dwm || pkill -9 sway)
-			$icon_rol Toggle WM          ^ 0 ^ confirm Toggle && sxmo_wmtoggle.sh
+			$icon_out Logout             ^ 0 ^ confirm Logout && (pkill dwm || swaymsg exit)
+			$([ -f /usr/share/xsessions/sxmo.desktop ] &&
+				[ -f /usr/share/wayland-sessions/swmo.desktop ] &&
+				echo "$icon_rol Toggle WM ^ 0 ^ confirm Toggle && sxmo_wmtoggle.sh"
+			)
 			$icon_rld Reboot             ^ 0 ^ confirm Reboot && sxmo_power.sh reboot
 			$icon_pwr Poweroff           ^ 0 ^ confirm Poweroff && sxmo_power.sh poweroff
 		"
@@ -326,18 +336,28 @@ case "$WMCLASS" in
 			WINNAME=less
 		elif printf %s "$WMNAME" | grep -qi -w "git \(blame\|diff\|grep\|help\|log\|stash\|tag\|var\)"; then
 			# These git commands only launch the pager.
-			exec "$0" "$WMCLASS ${PAGER:less}"
+			exec "$0" "$WMCLASS ${PAGER:-less}"
 		elif printf %s "$WMNAME" | grep -qi -w "git \(add\|bugreport\|commit\|merge\|notes\|rebase\|replace\|send-email\|svn\)"; then
 			# These git commands only launch the editor.
 			exec "$0" "$WMCLASS $EDITOR"
 		elif printf %s "$WMNAME" | grep -qi -w "git"; then
 			# git am, branch, config, tag (and other commands which launch both).
 			CHOICES="
-				$icon_fil ${PAGER:less} menu ^ 0 ^ sxmo_appmenu.sh '$WMCLASS ${PAGER:less}'
+				$icon_fil ${PAGER:-less} menu ^ 0 ^ sxmo_appmenu.sh '$WMCLASS ${PAGER:-less}'
 				$icon_edt $EDITOR menu ^ 0 ^ sxmo_appmenu.sh '$WMCLASS $EDITOR'
 				$icon_mnu Terminal menu ^ 0 ^ sxmo_appmenu.sh $WMCLASS
 			"
 			WINNAME=git
+		elif printf %s "$WMNAME" | grep -qi -w "senpai"; then
+			CHOICES="
+				$icon_aru Scroll up       ^ 1 ^ sxmo_type -k Prior
+				$icon_ard Scroll down     ^ 1 ^ sxmo_type -k Next
+				$icon_ac1 Previous Buffer ^ 1 ^ sxmo_type -M Alt -k Left
+				$icon_ac4 Next Buffer     ^ 1 ^ sxmo_type -M Alt -k Right
+				$icon_lst Toggle Channels ^ 0 ^ sxmo_type -k F7
+				$icon_usr Toggle Members  ^ 0 ^ sxmo_type -k F8
+			"
+			WINNAME=senpai
 		elif printf %s "$WMNAME" | grep -qi -w "weechat"; then
 			#weechat
 			CHOICES="
@@ -359,7 +379,18 @@ case "$WMCLASS" in
 				$icon_msg Reply          ^ 0 ^ sxmo_modemtext.sh sendtextmenu $number
 				$icon_phn Call           ^ 0 ^ sxmo_modemdial.sh $number
 				$([ -d "$SXMO_LOGDIR/$number/attachments" ] && echo "$icon_att View Attachments ^ 1 ^ sxmo_files.sh $SXMO_LOGDIR/$number/attachments --date-sort")
-				$(sxmo_contacts.sh --name "$number" | grep -q '???' && echo "$icon_usr Add to contacts ^ 1 ^ sxmo_contactmenu.sh newcontact $number")
+				$(
+
+				found_numbers="$(printf %s "$number" | xargs -I{} pn find "{}")"
+				printf "%s\n" "$found_numbers" | while read -r line; do
+					sxmo_contacts.sh --name "$line" | grep -q '???' && echo "$icon_usr Add $line ^ 1 ^ sxmo_contactmenu.sh newcontact $line"
+				done
+				# if this is a group chain, then allow to add entire chain as a contact too
+				if [ "$(printf "%s\n" "$found_numbers" | wc -l)" -gt 1 ]; then
+					sxmo_contacts.sh --name "$number" | grep -q '???' && echo "$icon_usr Add $number ^ 1 ^ sxmo_contactmenu.sh newcontact $number"
+				fi
+
+				)
 				$icon_aru Scroll up       ^ 1 ^ sxmo_type -M Shift -M Ctrl b
 				$icon_ard Scroll down     ^ 1 ^ sxmo_type -M Shift -M Ctrl f
 				$icon_mnu Terminal menu ^ 0 ^ sxmo_appmenu.sh $WMCLASS
@@ -522,6 +553,23 @@ case "$WMCLASS" in
 		"
 		WINNAME=Firefox
 		;;
+	*geopard*)
+		# Geopard
+		CHOICES="
+			$icon_pls New Tab            ^ 0 ^ sxmo_type -M Ctrl t
+			$icon_cls Close Tab          ^ 0 ^ sxmo_type -M Ctrl w
+			$icon_bok Open Bookmarks     ^ 0 ^ sxmo_type -M Ctrl b
+			$icon_pls Add Bookmark       ^ 0 ^ sxmo_type -M Ctrl d
+			$icon_edt Edit Bookmarks     ^ 0 ^ sxmo_keyboard.sh open && sxmo_terminal.sh $EDITOR ~/.local/share/geopard/bookmarks.gemini
+			$icon_zmi Increase Font Size ^ 1 ^ sxmo_type -M Ctrl -k plus
+			$icon_zmo Decrease Font Size ^ 1 ^ sxmo_type -M Ctrl -k minus
+			$icon_arl History Back       ^ 1 ^ sxmo_type -M Alt -k Left
+			$icon_arr History Forward    ^ 1 ^ sxmo_type -M Alt -k Right
+			$icon_fnd URL Bar            ^ 0 ^ sxmo_keyboard.sh open && sxmo_type -k F6
+			$icon_rld Refresh            ^ 0 ^ sxmo_type -k F6 -k Return
+			"
+		WINNAME=Geopard
+		;;
 	*lagrange*)
 		# Lagrange
 		CHOICES="
