@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 841e985f8678cabc7deb4363c1f78a47
+# configversion: b5fe8b5788a858c177d8fbebf45a284c
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -9,9 +9,9 @@
 . sxmo_common.sh
 
 # see networkmanager documentation for state names
-oldstate="$1"
+# oldstate="$1"
 newstate="$2"
-reason="$3" # 0 or 1
+# reason="$3" # 0 or 1
 
 case "$newstate" in
 	"locked")
