@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 9735676d54806bbbfa28842509599694
+# configversion: 29f7a3e2c1b73019e493083468e8a0ea
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -9,5 +9,7 @@
 #The following parameters are provided:
 #$1 = Number
 #$2 = Text
+# shellcheck source=scripts/core/sxmo_common.sh
+. sxmo_common.sh
 
-mpv --quiet --no-video /usr/share/sxmo/notify.ogg
+mpv --quiet --no-video "$(xdg_data_path sxmo/notify.ogg)"
