@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: d557f2116c20cba2d4125e5b274a5a16
+# configversion: 49e66c72839317096d7bb9d66cb51475
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -12,7 +12,22 @@
 # shellcheck source=scripts/core/sxmo_common.sh
 . sxmo_common.sh
 
-VPNDEVICE="$(nmcli con show 2>/dev/null | grep -E 'wireguard|vpn' | awk '{ print $1 }')"
+#colours using pango markup
+if [ "$SXMO_WM" = "sway" ]; then
+	SPAN_RED="<span foreground=\"#ff5454\">"
+	SPAN_GREEN="<span foreground=\"#54ff54\">"
+	SPAN_ORANGE="<span foreground=\"#ffa954\">"
+	BOLD="<b>"
+	ENDBOLD="</b>"
+	ENDSPAN="</span>"
+else
+	SPAN_RED=""
+	SPAN_GREEN=""
+	SPAN_ORANGE=""
+	BOLD=""
+	ENDBOLD=""
+	ENDSPAN=""
+fi
 
 set_time() {
 	date "+${SXMO_STATUS_DATE_FORMAT:-%H:%M}" | head -c -1 | sxmo_status.sh add 99-time
@@ -22,7 +37,8 @@ set_state() {
 	if grep -q unlock "$SXMO_STATE"; then
 		sxmo_status.sh del 0-state
 	else
-		tr '[:lower:]' '[:upper:]' < "$SXMO_STATE" | sxmo_status.sh add 0-state
+		STATE_LABEL=$(tr '[:lower:]' '[:upper:]' < "$SXMO_STATE")
+		echo "${SPAN_RED}${BOLD}${STATE_LABEL}${ENDBOLD}${ENDSPAN}" | sxmo_status.sh add 0-state
 	fi
 }
 
@@ -52,13 +68,13 @@ _modem() {
 		MODEMSTATUS="$(printf %s "$MMCLI" | jq -r .modem.generic.state)"
 		case "$MODEMSTATUS" in
 			locked)
-				printf "%s" "$icon_plk"
+				printf "%s%s%s" "$SPAN_RED" "$icon_plk" "$ENDSPAN"
 				;;
 			initializing)
 				printf "I"
 				;;
 			disabled) # low power state
-				printf "%s" "$icon_mdd"
+				printf "%s%s%s" "$SPAN_RED" "$icon_mdd" "$ENDSPAN"
 				;;
 			disabling)
 				printf ">%s" "$icon_mdd"
@@ -75,7 +91,7 @@ _modem() {
 			registered|connected|connecting|disconnecting)
 				MODEMSIGNAL="$(printf %s "$MMCLI" | jq -r '.modem.generic."signal-quality".value')"
 				if [ "$MODEMSIGNAL" -lt 20 ]; then
-					printf ""
+					printf "%s%s" "$SPAN_RED" "$ENDSPAN"
 				elif [ "$MODEMSIGNAL" -lt 40 ]; then
 					printf ""
 				elif [ "$MODEMSIGNAL" -lt 60 ]; then
@@ -90,7 +106,7 @@ _modem() {
 				# FAILED, UNKNOWN
 				# see https://www.freedesktop.org/software/ModemManager/doc/latest/ModemManager/ModemManager-Flags-and-Enumerations.html#MMModemState
 				sxmo_log "WARNING: MODEMSTATUS: $MODEMSTATUS"
-				printf "<%s>" "$MODEMSTATUS"
+				printf "%s" "$MODEMSTATUS"
 				;;
 		esac
 	fi
@@ -143,23 +159,31 @@ set_modem_monitor() {
 }
 
 set_wifi() {
-	WLANSTATE="$(tr -d "\n" < /sys/class/net/wlan0/operstate)"
-	if [ "$WLANSTATE" = "up" ]; then
-		sxmo_status.sh add 30-wifi-status "$icon_wif"
-	else
-		sxmo_status.sh del 30-wifi-status
-	fi
+	case "$(cat "/sys/class/net/$2/operstate")" in
+		"up") sxmo_status.sh add "30-network-$2-status" "$icon_wif" ;;
+		*) sxmo_status.sh del "30-network-$2-status" ;;
+	esac
 }
 
 set_vpn() {
-	VPNSTATE="$(nmcli device status | grep -E 'wireguard|vpn' | awk '{ print $3 }')"
-	if [ "$VPNDEVICE" != "--" ] && [ "$VPNSTATE" = "connected" ]; then
-		sxmo_status.sh add 30-vpn-status "$icon_key"
+	if nmcli -g GENERAL.STATE device show "$2" | grep connected > /dev/null; then
+		sxmo_status.sh add "30-network-$2-status" "$icon_key"
 	else
-		sxmo_status.sh del 30-vpn-status
+		sxmo_status.sh del "30-network-$2-status"
 	fi
 }
 
+# $1: type (reported by nmcli)
+# $2: interface name
+set_network() {
+	case "$1" in
+		wifi) set_wifi "$@" ;;
+		wireguard|vpn) set_vpn "$@" ;;
+		# the type will be empty if the interface disappeared
+		"") sxmo_status.sh del "30-network-$2-status" ;;
+	esac
+}
+
 _battery() {
 	count=0 # if multiple batteries, add space between them
 	for power_supply in /sys/class/power_supply/*; do
@@ -185,6 +209,14 @@ _battery() {
 				BATSTATUS="$(cut -c1 "$power_supply"/status)"
 			fi
 
+			# fixes a bug with keyboard case where
+			# /sys/class/power_supply/ip5xxx-charger/capacity
+			# exists but returns 'Not a tty'
+			if [ -z "$PCT" ]; then
+				printf "ERR"
+				continue
+			fi
+
 			# Treat 'Full' status as same as 'Charging'
 			if [ "$BATSTATUS" = "C" ] || [ "$BATSTATUS" = "F" ]; then
 				if [ "$PCT" -lt 20 ]; then
@@ -200,13 +232,13 @@ _battery() {
 				elif [ "$PCT" -lt 90 ]; then
 					printf ""
 				else
-					printf ""
+					printf "%s%s" "$SPAN_GREEN" "$ENDSPAN"
 				fi
 			else
 				if [ "$PCT" -lt 10 ]; then
-					printf ""
+					printf "%s%s" "$SPAN_RED" "$ENDSPAN"
 				elif [ "$PCT" -lt 20 ]; then
-					printf ""
+					printf "%s%s" "$SPAN_ORANGE" "$ENDSPAN"
 				elif [ "$PCT" -lt 30 ]; then
 					printf ""
 				elif [ "$PCT" -lt 40 ]; then
@@ -265,11 +297,9 @@ set_volume() {
 }
 
 case "$1" in
-	network_wlan0)
-		set_wifi
-		;;
-	network_$VPNDEVICE)
-		set_vpn
+	network)
+		shift
+		set_network "$@"
 		;;
 	time|call_duration|modem|modem_monitor|battery|volume|state)
 		set_"$1"
@@ -286,8 +316,6 @@ case "$1" in
 		set_call_duration
 		set_modem
 		set_modem_monitor
-		set_wifi
-		set_vpn
 		set_battery
 		set_volume
 		set_state
