@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: ae5192e49618b88d4cd29267c9fb872f
+# configversion: 0dfdb9562c33c964d7301a2ae4263259
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -12,5 +12,12 @@
 NUMBER="$1"
 CONTACTNAME="$(sxmo_contacts.sh | grep ": ${NUMBER}$" | cut -d: -f1)"
 [ "???" = "$CONTACTNAME" ] && CONTACTNAME="$CONTACTNAME ($NUMBER)"
+TERMNAME="$NUMBER SMS"
+export TERMNAME
 
-TERMNAME="$NUMBER SMS" sxmo_terminal.sh sh -c "tail -n9999 -f \"$SXMO_LOGDIR/$NUMBER/sms.txt\" | sed \"s|$NUMBER|$CONTACTNAME|g\""
+# If it's already open, switch to it.
+if [ "$SXMO_WM" = "sway" ]; then
+	regesc_termname="$(echo "$TERMNAME" | sed 's|+|\\+|g')"
+	swaymsg "[title=\"^$regesc_termname\$\"]" focus && exit 0
+fi
+sxmo_terminal.sh sh -c "tail -n9999 -f \"$SXMO_LOGDIR/$NUMBER/sms.txt\" | sed \"s|$NUMBER|$CONTACTNAME|g\""
