@@ -1,8 +1,10 @@
 #!/bin/sh
-# configversion: 16b0b4c25691f2fec3b1d6ac1ce91103
+# configversion: 1710eae12fe1e556c5e6fb8eb169ca81
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
+# include common definitions
+# shellcheck source=scripts/core/sxmo_common.sh
 . sxmo_common.sh
 
 UNSUSPENDREASON="$1"
@@ -18,8 +20,6 @@ if [ "$UNSUSPENDREASON" != "modem" ]; then
 	fi
 fi
 
-sxmo_hook_statusbar.sh time
-
 if [ "$UNSUSPENDREASON" = "rtc" ] || [ "$UNSUSPENDREASON" = "usb power" ]; then
 	if grep -q screenoff "$XDG_RUNTIME_DIR/sxmo.state"; then
 		# We stopped it in presuspend
