@@ -1,5 +1,5 @@
 #!/bin/sh
-# configversion: 040920a594309449edef1213b05965fd
+# configversion: c1ff69ed3bf1d509159e2010db4fe1ba
 # SPDX-License-Identifier: AGPL-3.0-only
 # Copyright 2022 Sxmo Contributors
 
@@ -46,4 +46,5 @@ else
 	esac
 fi
 
-sxmo_superd_signal.sh sxmo_desktop_widget -USR2
+sxmo_daemons.sh start periodic_state_mutex_check \
+	sxmo_run_aligned.sh 60 sxmo_uniq_exec.sh sxmo_hook_check_state_mutexes.sh
